# 変更履歴

全てのバージョンの重要な変更はこのファイルに記録されます。

フォーマットは[Keep a Changelog](https://keepachangelog.com/ja/)に基づいています。

## [v0.0.4] - 2025-03-09
### 修正
- テストコードの修正：モックオブジェクトに必要な属性（url, headers, text）を追加
- VCRテストの安定性向上

## [v0.0.3] - 2025-02-21
### 追加
- CLIサポートの追加（uvxコマンドを使用）
- CLIコマンドへの進捗表示機能の追加

### 変更
- README-ja.mdの削除（メインのREADMEが日本語のため）
- CLIドキュメントの改善（テンプレートIDのパラメータ説明を明確化）

## [v0.0.2] - 2025-02-17
### 追加
- PyPIパッケージ配布対応
- VCRテストの追加
- 最小限の利用例の追加（クライアントとLangChainツール）
- .vscode設定の追加（開発環境の統一化）

### 変更
- ライブラリのフォルダ構造の整理
- ドキュメントの整備と改善

### 修正
- デプロイフローの修正
- テストの修正とVCRカセットの更新
